# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class AddCloudAccessRequest(DaraModel):
    def __init__(
        self,
        cloud_name: str = None,
        secret_id: str = None,
        secret_key: str = None,
    ):
        self.cloud_name = cloud_name
        self.secret_id = secret_id
        self.secret_key = secret_key

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cloud_name is not None:
            result['CloudName'] = self.cloud_name

        if self.secret_id is not None:
            result['SecretId'] = self.secret_id

        if self.secret_key is not None:
            result['SecretKey'] = self.secret_key

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CloudName') is not None:
            self.cloud_name = m.get('CloudName')

        if m.get('SecretId') is not None:
            self.secret_id = m.get('SecretId')

        if m.get('SecretKey') is not None:
            self.secret_key = m.get('SecretKey')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._add_cloud_access_request import AddCloudAccessRequest
from ._add_cloud_access_response_body import AddCloudAccessResponseBody
from ._add_cloud_access_response import AddCloudAccessResponse
from ._apply_certificate_request import ApplyCertificateRequest
from ._apply_certificate_response_body import ApplyCertificateResponseBody
from ._apply_certificate_response import ApplyCertificateResponse
from ._cancel_certificate_for_package_request_request import CancelCertificateForPackageRequestRequest
from ._cancel_certificate_for_package_request_response_body import CancelCertificateForPackageRequestResponseBody
from ._cancel_certificate_for_package_request_response import CancelCertificateForPackageRequestResponse
from ._cancel_order_request_request import CancelOrderRequestRequest
from ._cancel_order_request_response_body import CancelOrderRequestResponseBody
from ._cancel_order_request_response import CancelOrderRequestResponse
from ._cancel_pending_certificate_request import CancelPendingCertificateRequest
from ._cancel_pending_certificate_response_body import CancelPendingCertificateResponseBody
from ._cancel_pending_certificate_response import CancelPendingCertificateResponse
from ._create_certificate_for_package_request_request import CreateCertificateForPackageRequestRequest
from ._create_certificate_for_package_request_response_body import CreateCertificateForPackageRequestResponseBody
from ._create_certificate_for_package_request_response import CreateCertificateForPackageRequestResponse
from ._create_certificate_request_request import CreateCertificateRequestRequest
from ._create_certificate_request_response_body import CreateCertificateRequestResponseBody
from ._create_certificate_request_response import CreateCertificateRequestResponse
from ._create_certificate_with_csr_request_request import CreateCertificateWithCsrRequestRequest
from ._create_certificate_with_csr_request_response_body import CreateCertificateWithCsrRequestResponseBody
from ._create_certificate_with_csr_request_response import CreateCertificateWithCsrRequestResponse
from ._create_csr_request import CreateCsrRequest
from ._create_csr_response_body import CreateCsrResponseBody
from ._create_csr_response import CreateCsrResponse
from ._create_deployment_job_request import CreateDeploymentJobRequest
from ._create_deployment_job_response_body import CreateDeploymentJobResponseBody
from ._create_deployment_job_response import CreateDeploymentJobResponse
from ._create_whclient_certificate_request import CreateWHClientCertificateRequest
from ._create_whclient_certificate_response_body import CreateWHClientCertificateResponseBody
from ._create_whclient_certificate_response import CreateWHClientCertificateResponse
from ._create_warehouse_request import CreateWarehouseRequest
from ._create_warehouse_response_body import CreateWarehouseResponseBody
from ._create_warehouse_response import CreateWarehouseResponse
from ._decrypt_request import DecryptRequest
from ._decrypt_response_body import DecryptResponseBody
from ._decrypt_response import DecryptResponse
from ._delete_certificate_request_request import DeleteCertificateRequestRequest
from ._delete_certificate_request_response_body import DeleteCertificateRequestResponseBody
from ._delete_certificate_request_response import DeleteCertificateRequestResponse
from ._delete_cloud_access_request import DeleteCloudAccessRequest
from ._delete_cloud_access_response_body import DeleteCloudAccessResponseBody
from ._delete_cloud_access_response import DeleteCloudAccessResponse
from ._delete_csr_request import DeleteCsrRequest
from ._delete_csr_response_body import DeleteCsrResponseBody
from ._delete_csr_response import DeleteCsrResponse
from ._delete_deployment_job_request import DeleteDeploymentJobRequest
from ._delete_deployment_job_response_body import DeleteDeploymentJobResponseBody
from ._delete_deployment_job_response import DeleteDeploymentJobResponse
from ._delete_instance_request import DeleteInstanceRequest
from ._delete_instance_response_body import DeleteInstanceResponseBody
from ._delete_instance_response import DeleteInstanceResponse
from ._delete_pcacert_request import DeletePCACertRequest
from ._delete_pcacert_response_body import DeletePCACertResponseBody
from ._delete_pcacert_response import DeletePCACertResponse
from ._delete_user_certificate_request import DeleteUserCertificateRequest
from ._delete_user_certificate_response_body import DeleteUserCertificateResponseBody
from ._delete_user_certificate_response import DeleteUserCertificateResponse
from ._delete_warehouse_request import DeleteWarehouseRequest
from ._delete_warehouse_response_body import DeleteWarehouseResponseBody
from ._delete_warehouse_response import DeleteWarehouseResponse
from ._delete_worker_resource_request import DeleteWorkerResourceRequest
from ._delete_worker_resource_response_body import DeleteWorkerResourceResponseBody
from ._delete_worker_resource_response import DeleteWorkerResourceResponse
from ._describe_certificate_state_request import DescribeCertificateStateRequest
from ._describe_certificate_state_response_body import DescribeCertificateStateResponseBody
from ._describe_certificate_state_response import DescribeCertificateStateResponse
from ._describe_cloud_resource_status_request import DescribeCloudResourceStatusRequest
from ._describe_cloud_resource_status_response_body import DescribeCloudResourceStatusResponseBody
from ._describe_cloud_resource_status_response import DescribeCloudResourceStatusResponse
from ._describe_deployment_job_request import DescribeDeploymentJobRequest
from ._describe_deployment_job_response_body import DescribeDeploymentJobResponseBody
from ._describe_deployment_job_response import DescribeDeploymentJobResponse
from ._describe_deployment_job_status_request import DescribeDeploymentJobStatusRequest
from ._describe_deployment_job_status_response_body import DescribeDeploymentJobStatusResponseBody
from ._describe_deployment_job_status_response import DescribeDeploymentJobStatusResponse
from ._describe_package_state_request import DescribePackageStateRequest
from ._describe_package_state_response_body import DescribePackageStateResponseBody
from ._describe_package_state_response import DescribePackageStateResponse
from ._describe_warehouse_cert_request import DescribeWarehouseCertRequest
from ._describe_warehouse_cert_response_body import DescribeWarehouseCertResponseBody
from ._describe_warehouse_cert_response import DescribeWarehouseCertResponse
from ._encrypt_request import EncryptRequest
from ._encrypt_response_body import EncryptResponseBody
from ._encrypt_response import EncryptResponse
from ._get_asset_count_response_body import GetAssetCountResponseBody
from ._get_asset_count_response import GetAssetCountResponse
from ._get_cert_warehouse_quota_response_body import GetCertWarehouseQuotaResponseBody
from ._get_cert_warehouse_quota_response import GetCertWarehouseQuotaResponse
from ._get_certificate_detail_request import GetCertificateDetailRequest
from ._get_certificate_detail_response_body import GetCertificateDetailResponseBody
from ._get_certificate_detail_response import GetCertificateDetailResponse
from ._get_csr_detail_request import GetCsrDetailRequest
from ._get_csr_detail_response_body import GetCsrDetailResponseBody
from ._get_csr_detail_response import GetCsrDetailResponse
from ._get_instance_detail_request import GetInstanceDetailRequest
from ._get_instance_detail_response_body import GetInstanceDetailResponseBody
from ._get_instance_detail_response import GetInstanceDetailResponse
from ._get_instance_summary_request import GetInstanceSummaryRequest
from ._get_instance_summary_response_body import GetInstanceSummaryResponseBody
from ._get_instance_summary_response import GetInstanceSummaryResponse
from ._get_risk_count_response_body import GetRiskCountResponseBody
from ._get_risk_count_response import GetRiskCountResponse
from ._get_task_attribute_request import GetTaskAttributeRequest
from ._get_task_attribute_response_body import GetTaskAttributeResponseBody
from ._get_task_attribute_response import GetTaskAttributeResponse
from ._get_user_certificate_detail_request import GetUserCertificateDetailRequest
from ._get_user_certificate_detail_response_body import GetUserCertificateDetailResponseBody
from ._get_user_certificate_detail_response import GetUserCertificateDetailResponse
from ._list_asset_count_request import ListAssetCountRequest
from ._list_asset_count_response_body import ListAssetCountResponseBody
from ._list_asset_count_response import ListAssetCountResponse
from ._list_cert_request import ListCertRequest
from ._list_cert_response_body import ListCertResponseBody
from ._list_cert_response import ListCertResponse
from ._list_cert_warehouse_request import ListCertWarehouseRequest
from ._list_cert_warehouse_response_body import ListCertWarehouseResponseBody
from ._list_cert_warehouse_response import ListCertWarehouseResponse
from ._list_certificates_request import ListCertificatesRequest
from ._list_certificates_response_body import ListCertificatesResponseBody
from ._list_certificates_response import ListCertificatesResponse
from ._list_cloud_access_request import ListCloudAccessRequest
from ._list_cloud_access_response_body import ListCloudAccessResponseBody
from ._list_cloud_access_response import ListCloudAccessResponse
from ._list_cloud_resources_request import ListCloudResourcesRequest
from ._list_cloud_resources_shrink_request import ListCloudResourcesShrinkRequest
from ._list_cloud_resources_response_body import ListCloudResourcesResponseBody
from ._list_cloud_resources_response import ListCloudResourcesResponse
from ._list_contact_request import ListContactRequest
from ._list_contact_response_body import ListContactResponseBody
from ._list_contact_response import ListContactResponse
from ._list_csr_request import ListCsrRequest
from ._list_csr_response_body import ListCsrResponseBody
from ._list_csr_response import ListCsrResponse
from ._list_deployment_job_request import ListDeploymentJobRequest
from ._list_deployment_job_response_body import ListDeploymentJobResponseBody
from ._list_deployment_job_response import ListDeploymentJobResponse
from ._list_deployment_job_cert_request import ListDeploymentJobCertRequest
from ._list_deployment_job_cert_response_body import ListDeploymentJobCertResponseBody
from ._list_deployment_job_cert_response import ListDeploymentJobCertResponse
from ._list_deployment_job_resource_request import ListDeploymentJobResourceRequest
from ._list_deployment_job_resource_response_body import ListDeploymentJobResourceResponseBody
from ._list_deployment_job_resource_response import ListDeploymentJobResourceResponse
from ._list_instances_request import ListInstancesRequest
from ._list_instances_response_body import ListInstancesResponseBody
from ._list_instances_response import ListInstancesResponse
from ._list_user_certificate_order_request import ListUserCertificateOrderRequest
from ._list_user_certificate_order_response_body import ListUserCertificateOrderResponseBody
from ._list_user_certificate_order_response import ListUserCertificateOrderResponse
from ._list_warehouse_request import ListWarehouseRequest
from ._list_warehouse_shrink_request import ListWarehouseShrinkRequest
from ._list_warehouse_response_body import ListWarehouseResponseBody
from ._list_warehouse_response import ListWarehouseResponse
from ._list_worker_resource_request import ListWorkerResourceRequest
from ._list_worker_resource_response_body import ListWorkerResourceResponseBody
from ._list_worker_resource_response import ListWorkerResourceResponse
from ._move_resource_group_request import MoveResourceGroupRequest
from ._move_resource_group_response_body import MoveResourceGroupResponseBody
from ._move_resource_group_response import MoveResourceGroupResponse
from ._refund_instance_request import RefundInstanceRequest
from ._refund_instance_response_body import RefundInstanceResponseBody
from ._refund_instance_response import RefundInstanceResponse
from ._renew_certificate_order_for_package_request_request import RenewCertificateOrderForPackageRequestRequest
from ._renew_certificate_order_for_package_request_response_body import RenewCertificateOrderForPackageRequestResponseBody
from ._renew_certificate_order_for_package_request_response import RenewCertificateOrderForPackageRequestResponse
from ._revoke_certificate_request import RevokeCertificateRequest
from ._revoke_certificate_response_body import RevokeCertificateResponseBody
from ._revoke_certificate_response import RevokeCertificateResponse
from ._revoke_whclient_certificate_request import RevokeWHClientCertificateRequest
from ._revoke_whclient_certificate_response_body import RevokeWHClientCertificateResponseBody
from ._revoke_whclient_certificate_response import RevokeWHClientCertificateResponse
from ._sign_request import SignRequest
from ._sign_response_body import SignResponseBody
from ._sign_response import SignResponse
from ._update_csr_request import UpdateCsrRequest
from ._update_csr_response_body import UpdateCsrResponseBody
from ._update_csr_response import UpdateCsrResponse
from ._update_deployment_job_request import UpdateDeploymentJobRequest
from ._update_deployment_job_response_body import UpdateDeploymentJobResponseBody
from ._update_deployment_job_response import UpdateDeploymentJobResponse
from ._update_deployment_job_status_request import UpdateDeploymentJobStatusRequest
from ._update_deployment_job_status_response_body import UpdateDeploymentJobStatusResponseBody
from ._update_deployment_job_status_response import UpdateDeploymentJobStatusResponse
from ._update_instance_request import UpdateInstanceRequest
from ._update_instance_response_body import UpdateInstanceResponseBody
from ._update_instance_response import UpdateInstanceResponse
from ._update_worker_resource_status_request import UpdateWorkerResourceStatusRequest
from ._update_worker_resource_status_response_body import UpdateWorkerResourceStatusResponseBody
from ._update_worker_resource_status_response import UpdateWorkerResourceStatusResponse
from ._upload_csr_request import UploadCsrRequest
from ._upload_csr_response_body import UploadCsrResponseBody
from ._upload_csr_response import UploadCsrResponse
from ._upload_pcacert_request import UploadPCACertRequest
from ._upload_pcacert_response_body import UploadPCACertResponseBody
from ._upload_pcacert_response import UploadPCACertResponse
from ._upload_user_certificate_request import UploadUserCertificateRequest
from ._upload_user_certificate_response_body import UploadUserCertificateResponseBody
from ._upload_user_certificate_response import UploadUserCertificateResponse
from ._verify_request import VerifyRequest
from ._verify_response_body import VerifyResponseBody
from ._verify_response import VerifyResponse
from ._create_certificate_for_package_request_request import CreateCertificateForPackageRequestRequestTags
from ._create_certificate_request_request import CreateCertificateRequestRequestTags
from ._create_certificate_with_csr_request_request import CreateCertificateWithCsrRequestRequestTags
from ._describe_cloud_resource_status_response_body import DescribeCloudResourceStatusResponseBodyData
from ._describe_deployment_job_response_body import DescribeDeploymentJobResponseBodyCasContacts
from ._describe_deployment_job_status_response_body import DescribeDeploymentJobStatusResponseBodyProductWorkerCount
from ._get_certificate_detail_response_body import GetCertificateDetailResponseBodyCertificateChainList
from ._get_certificate_detail_response_body import GetCertificateDetailResponseBodyTags
from ._get_instance_detail_response_body import GetInstanceDetailResponseBodyDingGroupList
from ._get_instance_detail_response_body import GetInstanceDetailResponseBodyDomainValidationList
from ._get_instance_detail_response_body import GetInstanceDetailResponseBodyTags
from ._get_user_certificate_detail_response_body import GetUserCertificateDetailResponseBodyCertChain
from ._get_user_certificate_detail_response_body import GetUserCertificateDetailResponseBodyTags
from ._list_asset_count_response_body import ListAssetCountResponseBodyAssetCountList
from ._list_cert_response_body import ListCertResponseBodyCertList
from ._list_cert_warehouse_response_body import ListCertWarehouseResponseBodyCertWarehouseList
from ._list_certificates_response_body import ListCertificatesResponseBodyCertificateList
from ._list_cloud_access_response_body import ListCloudAccessResponseBodyCloudAccessList
from ._list_cloud_resources_response_body import ListCloudResourcesResponseBodyData
from ._list_contact_response_body import ListContactResponseBodyContactList
from ._list_csr_response_body import ListCsrResponseBodyCsrList
from ._list_deployment_job_response_body import ListDeploymentJobResponseBodyData
from ._list_deployment_job_cert_response_body import ListDeploymentJobCertResponseBodyData
from ._list_deployment_job_resource_response_body import ListDeploymentJobResourceResponseBodyData
from ._list_instances_response_body import ListInstancesResponseBodyInstanceList
from ._list_user_certificate_order_response_body import ListUserCertificateOrderResponseBodyCertificateOrderList
from ._list_warehouse_response_body import ListWarehouseResponseBodyData
from ._list_worker_resource_response_body import ListWorkerResourceResponseBodyData
from ._renew_certificate_order_for_package_request_request import RenewCertificateOrderForPackageRequestRequestTags
from ._update_instance_request import UpdateInstanceRequestTags
from ._upload_user_certificate_request import UploadUserCertificateRequestTags

__all__ = [
    AddCloudAccessRequest,
    AddCloudAccessResponseBody,
    AddCloudAccessResponse,
    ApplyCertificateRequest,
    ApplyCertificateResponseBody,
    ApplyCertificateResponse,
    CancelCertificateForPackageRequestRequest,
    CancelCertificateForPackageRequestResponseBody,
    CancelCertificateForPackageRequestResponse,
    CancelOrderRequestRequest,
    CancelOrderRequestResponseBody,
    CancelOrderRequestResponse,
    CancelPendingCertificateRequest,
    CancelPendingCertificateResponseBody,
    CancelPendingCertificateResponse,
    CreateCertificateForPackageRequestRequest,
    CreateCertificateForPackageRequestResponseBody,
    CreateCertificateForPackageRequestResponse,
    CreateCertificateRequestRequest,
    CreateCertificateRequestResponseBody,
    CreateCertificateRequestResponse,
    CreateCertificateWithCsrRequestRequest,
    CreateCertificateWithCsrRequestResponseBody,
    CreateCertificateWithCsrRequestResponse,
    CreateCsrRequest,
    CreateCsrResponseBody,
    CreateCsrResponse,
    CreateDeploymentJobRequest,
    CreateDeploymentJobResponseBody,
    CreateDeploymentJobResponse,
    CreateWHClientCertificateRequest,
    CreateWHClientCertificateResponseBody,
    CreateWHClientCertificateResponse,
    CreateWarehouseRequest,
    CreateWarehouseResponseBody,
    CreateWarehouseResponse,
    DecryptRequest,
    DecryptResponseBody,
    DecryptResponse,
    DeleteCertificateRequestRequest,
    DeleteCertificateRequestResponseBody,
    DeleteCertificateRequestResponse,
    DeleteCloudAccessRequest,
    DeleteCloudAccessResponseBody,
    DeleteCloudAccessResponse,
    DeleteCsrRequest,
    DeleteCsrResponseBody,
    DeleteCsrResponse,
    DeleteDeploymentJobRequest,
    DeleteDeploymentJobResponseBody,
    DeleteDeploymentJobResponse,
    DeleteInstanceRequest,
    DeleteInstanceResponseBody,
    DeleteInstanceResponse,
    DeletePCACertRequest,
    DeletePCACertResponseBody,
    DeletePCACertResponse,
    DeleteUserCertificateRequest,
    DeleteUserCertificateResponseBody,
    DeleteUserCertificateResponse,
    DeleteWarehouseRequest,
    DeleteWarehouseResponseBody,
    DeleteWarehouseResponse,
    DeleteWorkerResourceRequest,
    DeleteWorkerResourceResponseBody,
    DeleteWorkerResourceResponse,
    DescribeCertificateStateRequest,
    DescribeCertificateStateResponseBody,
    DescribeCertificateStateResponse,
    DescribeCloudResourceStatusRequest,
    DescribeCloudResourceStatusResponseBody,
    DescribeCloudResourceStatusResponse,
    DescribeDeploymentJobRequest,
    DescribeDeploymentJobResponseBody,
    DescribeDeploymentJobResponse,
    DescribeDeploymentJobStatusRequest,
    DescribeDeploymentJobStatusResponseBody,
    DescribeDeploymentJobStatusResponse,
    DescribePackageStateRequest,
    DescribePackageStateResponseBody,
    DescribePackageStateResponse,
    DescribeWarehouseCertRequest,
    DescribeWarehouseCertResponseBody,
    DescribeWarehouseCertResponse,
    EncryptRequest,
    EncryptResponseBody,
    EncryptResponse,
    GetAssetCountResponseBody,
    GetAssetCountResponse,
    GetCertWarehouseQuotaResponseBody,
    GetCertWarehouseQuotaResponse,
    GetCertificateDetailRequest,
    GetCertificateDetailResponseBody,
    GetCertificateDetailResponse,
    GetCsrDetailRequest,
    GetCsrDetailResponseBody,
    GetCsrDetailResponse,
    GetInstanceDetailRequest,
    GetInstanceDetailResponseBody,
    GetInstanceDetailResponse,
    GetInstanceSummaryRequest,
    GetInstanceSummaryResponseBody,
    GetInstanceSummaryResponse,
    GetRiskCountResponseBody,
    GetRiskCountResponse,
    GetTaskAttributeRequest,
    GetTaskAttributeResponseBody,
    GetTaskAttributeResponse,
    GetUserCertificateDetailRequest,
    GetUserCertificateDetailResponseBody,
    GetUserCertificateDetailResponse,
    ListAssetCountRequest,
    ListAssetCountResponseBody,
    ListAssetCountResponse,
    ListCertRequest,
    ListCertResponseBody,
    ListCertResponse,
    ListCertWarehouseRequest,
    ListCertWarehouseResponseBody,
    ListCertWarehouseResponse,
    ListCertificatesRequest,
    ListCertificatesResponseBody,
    ListCertificatesResponse,
    ListCloudAccessRequest,
    ListCloudAccessResponseBody,
    ListCloudAccessResponse,
    ListCloudResourcesRequest,
    ListCloudResourcesShrinkRequest,
    ListCloudResourcesResponseBody,
    ListCloudResourcesResponse,
    ListContactRequest,
    ListContactResponseBody,
    ListContactResponse,
    ListCsrRequest,
    ListCsrResponseBody,
    ListCsrResponse,
    ListDeploymentJobRequest,
    ListDeploymentJobResponseBody,
    ListDeploymentJobResponse,
    ListDeploymentJobCertRequest,
    ListDeploymentJobCertResponseBody,
    ListDeploymentJobCertResponse,
    ListDeploymentJobResourceRequest,
    ListDeploymentJobResourceResponseBody,
    ListDeploymentJobResourceResponse,
    ListInstancesRequest,
    ListInstancesResponseBody,
    ListInstancesResponse,
    ListUserCertificateOrderRequest,
    ListUserCertificateOrderResponseBody,
    ListUserCertificateOrderResponse,
    ListWarehouseRequest,
    ListWarehouseShrinkRequest,
    ListWarehouseResponseBody,
    ListWarehouseResponse,
    ListWorkerResourceRequest,
    ListWorkerResourceResponseBody,
    ListWorkerResourceResponse,
    MoveResourceGroupRequest,
    MoveResourceGroupResponseBody,
    MoveResourceGroupResponse,
    RefundInstanceRequest,
    RefundInstanceResponseBody,
    RefundInstanceResponse,
    RenewCertificateOrderForPackageRequestRequest,
    RenewCertificateOrderForPackageRequestResponseBody,
    RenewCertificateOrderForPackageRequestResponse,
    RevokeCertificateRequest,
    RevokeCertificateResponseBody,
    RevokeCertificateResponse,
    RevokeWHClientCertificateRequest,
    RevokeWHClientCertificateResponseBody,
    RevokeWHClientCertificateResponse,
    SignRequest,
    SignResponseBody,
    SignResponse,
    UpdateCsrRequest,
    UpdateCsrResponseBody,
    UpdateCsrResponse,
    UpdateDeploymentJobRequest,
    UpdateDeploymentJobResponseBody,
    UpdateDeploymentJobResponse,
    UpdateDeploymentJobStatusRequest,
    UpdateDeploymentJobStatusResponseBody,
    UpdateDeploymentJobStatusResponse,
    UpdateInstanceRequest,
    UpdateInstanceResponseBody,
    UpdateInstanceResponse,
    UpdateWorkerResourceStatusRequest,
    UpdateWorkerResourceStatusResponseBody,
    UpdateWorkerResourceStatusResponse,
    UploadCsrRequest,
    UploadCsrResponseBody,
    UploadCsrResponse,
    UploadPCACertRequest,
    UploadPCACertResponseBody,
    UploadPCACertResponse,
    UploadUserCertificateRequest,
    UploadUserCertificateResponseBody,
    UploadUserCertificateResponse,
    VerifyRequest,
    VerifyResponseBody,
    VerifyResponse,
    CreateCertificateForPackageRequestRequestTags,
    CreateCertificateRequestRequestTags,
    CreateCertificateWithCsrRequestRequestTags,
    DescribeCloudResourceStatusResponseBodyData,
    DescribeDeploymentJobResponseBodyCasContacts,
    DescribeDeploymentJobStatusResponseBodyProductWorkerCount,
    GetCertificateDetailResponseBodyCertificateChainList,
    GetCertificateDetailResponseBodyTags,
    GetInstanceDetailResponseBodyDingGroupList,
    GetInstanceDetailResponseBodyDomainValidationList,
    GetInstanceDetailResponseBodyTags,
    GetUserCertificateDetailResponseBodyCertChain,
    GetUserCertificateDetailResponseBodyTags,
    ListAssetCountResponseBodyAssetCountList,
    ListCertResponseBodyCertList,
    ListCertWarehouseResponseBodyCertWarehouseList,
    ListCertificatesResponseBodyCertificateList,
    ListCloudAccessResponseBodyCloudAccessList,
    ListCloudResourcesResponseBodyData,
    ListContactResponseBodyContactList,
    ListCsrResponseBodyCsrList,
    ListDeploymentJobResponseBodyData,
    ListDeploymentJobCertResponseBodyData,
    ListDeploymentJobResourceResponseBodyData,
    ListInstancesResponseBodyInstanceList,
    ListUserCertificateOrderResponseBodyCertificateOrderList,
    ListWarehouseResponseBodyData,
    ListWorkerResourceResponseBodyData,
    RenewCertificateOrderForPackageRequestRequestTags,
    UpdateInstanceRequestTags,
    UploadUserCertificateRequestTags
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetCertWarehouseQuotaResponseBody(DaraModel):
    def __init__(
        self,
        app_total_quota: int = None,
        app_use_count: int = None,
        request_id: str = None,
        total_quota: int = None,
        use_count: int = None,
    ):
        self.app_total_quota = app_total_quota
        self.app_use_count = app_use_count
        # The ID of the request, which is used to locate and troubleshoot issues.
        self.request_id = request_id
        # The total quota for certificate repositories, including the free quota and purchased quota.
        self.total_quota = total_quota
        # The used quota.
        self.use_count = use_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.app_total_quota is not None:
            result['AppTotalQuota'] = self.app_total_quota

        if self.app_use_count is not None:
            result['AppUseCount'] = self.app_use_count

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.total_quota is not None:
            result['TotalQuota'] = self.total_quota

        if self.use_count is not None:
            result['UseCount'] = self.use_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AppTotalQuota') is not None:
            self.app_total_quota = m.get('AppTotalQuota')

        if m.get('AppUseCount') is not None:
            self.app_use_count = m.get('AppUseCount')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('TotalQuota') is not None:
            self.total_quota = m.get('TotalQuota')

        if m.get('UseCount') is not None:
            self.use_count = m.get('UseCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class EncryptRequest(DaraModel):
    def __init__(
        self,
        algorithm: str = None,
        cert_identifier: str = None,
        custom_identifier: str = None,
        message_type: str = None,
        plaintext: str = None,
        warehouse_id: int = None,
    ):
        # The encryption algorithm. Valid values:
        # 
        # *   **RSAES_OAEP_SHA_1**
        # *   **RSAES_OAEP_SHA_256**
        # *   **SM2PKE**
        # 
        # This parameter is required.
        self.algorithm = algorithm
        # The unique identifier of the certificate. You can call the [ListCert](https://help.aliyun.com/document_detail/455806.html) operation to obtain the identifier.
        # 
        # *   If the certificate is an SSL certificate, the value of this parameter must be in the {Certificate ID}-cn-hangzhou format.
        # *   If the certificate is a private certificate, the value of this parameter must be the value of the Identifier field for the private certificate.
        self.cert_identifier = cert_identifier
        self.custom_identifier = custom_identifier
        # The value type of the Message parameter. Valid values:
        # 
        # *   RAW: The value of the Plaintext parameter is directly encrypted. This is the default value.
        # *   Base64: The value of the Plaintext parameter is Base64-encoded data. The data is decoded and then encrypted.
        self.message_type = message_type
        # The data that you want to encrypt. The value of this parameter can be raw data or Base64-encoded data. For more information, see the description of the MessageType parameter. For example, if the hexadecimal data that you want to encrypt is `[0x31, 0x32, 0x33, 0x34]`, the Base64-encoded data is MTIzNA==. The size of data that can be encrypted varies based on the encryption algorithm that you use. The following list describes the relationship between the encryption algorithms and data sizes:
        # 
        # *   **RSAES_OAEP_SHA_1**: 214 bytes
        # *   **RSAES_OAEP_SHA_256**: 190 bytes
        # *   **SM2PKE**: 6,047 bytes
        # 
        # This parameter is required.
        self.plaintext = plaintext
        self.warehouse_id = warehouse_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.cert_identifier is not None:
            result['CertIdentifier'] = self.cert_identifier

        if self.custom_identifier is not None:
            result['CustomIdentifier'] = self.custom_identifier

        if self.message_type is not None:
            result['MessageType'] = self.message_type

        if self.plaintext is not None:
            result['Plaintext'] = self.plaintext

        if self.warehouse_id is not None:
            result['WarehouseId'] = self.warehouse_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('CertIdentifier') is not None:
            self.cert_identifier = m.get('CertIdentifier')

        if m.get('CustomIdentifier') is not None:
            self.custom_identifier = m.get('CustomIdentifier')

        if m.get('MessageType') is not None:
            self.message_type = m.get('MessageType')

        if m.get('Plaintext') is not None:
            self.plaintext = m.get('Plaintext')

        if m.get('WarehouseId') is not None:
            self.warehouse_id = m.get('WarehouseId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribeCertificateStateResponseBody(DaraModel):
    def __init__(
        self,
        cert_id: str = None,
        certificate: str = None,
        content: str = None,
        domain: str = None,
        private_key: str = None,
        record_domain: str = None,
        record_type: str = None,
        record_value: str = None,
        request_id: str = None,
        type: str = None,
        uri: str = None,
        validate_type: str = None,
    ):
        self.cert_id = cert_id
        # The content of the certificate in the PEM format. For more information about the PEM format and how to convert certificate formats, see [What formats are used for mainstream digital certificates?](https://help.aliyun.com/document_detail/42214.html)
        # 
        # >  This parameter is returned only when the value of the **Type** parameter is **certificate**. The value certificate indicates that the certificate is issued.
        self.certificate = certificate
        # The content that you need to write to the newly created file when you use the file verification method.
        # 
        # >  This parameter is returned only when the value of the **Type** parameter is **domain_verify** and the value of the **ValidateType** parameter is **FILE**. The value domain_verify indicates that the verification of the domain name ownership is not complete, and the value FILE indicates that the file verification method is used.
        self.content = content
        # The domain name to be verified when you use the file verification method. You must connect to the DNS server of the domain name and create a file on the server. The file is specified by the **Uri** parameter.
        # 
        # >  This parameter is returned only when the value of the **Type** parameter is **domain_verify** and the value of the **ValidateType** parameter is **FILE**. The value domain_verify indicates that the verification of the domain name ownership is not complete, and the value FILE indicates that the file verification method is used.
        self.domain = domain
        # The private key of the certificate in the PEM format. For more information about the PEM format and how to convert certificate formats, see [What formats are used for mainstream digital certificates?](https://help.aliyun.com/document_detail/42214.html)
        # 
        # >  This parameter is returned only when the value of the **Type** parameter is **certificate**. The value certificate indicates that the certificate is issued.
        self.private_key = private_key
        # The DNS record that you need to manage when you use the DNS verification method.
        # 
        # >  This parameter is returned only when the value of the **Type** parameter is **domain_verify** and the value of the **ValidateType** parameter is **DNS**. The value domain_verify indicates that the verification of the domain name ownership is not complete, and the value DNS indicates that the DNS verification method is used.
        self.record_domain = record_domain
        # The type of the DNS record that you need to add when you use the DNS verification method. Valid values:
        # 
        # *   **TXT**
        # *   **CNAME**
        # 
        # >  This parameter is returned only when the value of the **Type** parameter is **domain_verify** and the value of the **ValidateType** parameter is **DNS**. The value domain_verify indicates that the verification of the domain name ownership is not complete.
        self.record_type = record_type
        # You need to add a TXT record to the DNS records only when you use the DNS verification method.
        # 
        # >  This parameter is returned only when the value of the **Type** parameter is **domain_verify** and the value of the **ValidateType** parameter is **DNS**. The value domain_verify indicates that the verification of the domain name ownership is not complete, and the value DNS indicates that the DNS verification method is used.
        self.record_value = record_value
        # The ID of the request.
        self.request_id = request_id
        # The status of the certificate application order. Valid values:
        # 
        # *   **domain_verify**: **pending review**, which indicates that you have not completed the verification of the domain name ownership after you submit the certificate application.
        #      >After you submit a certificate application, you must manually complete the verification of the domain name ownership. The CA reviews the certificate application only after the verification is complete. If you have not completed the verification of the domain name ownership, you can complete the verification based on the data returned by this operation.
        # 
        # *   **process**: **being reviewed**, which indicates that the certificate application is being reviewed by the CA.
        # 
        # *   **verify_fail**: **review failed**, which indicates that the certificate application failed to be reviewed.
        #     >  If a certificate application fails to be reviewed, the information that you specified in the certificate application may be incorrect. We recommend that you call the [DeleteCertificateRequest](https://help.aliyun.com/document_detail/164109.html) operation to delete the certificate application order and resubmit a certificate application. After the order is deleted, the quota that is consumed for the order is released.
        # 
        # *   **certificate**: **issued**, which indicates that the certificate is issued.
        # 
        # *   **payed**: **pending application**, which indicates that you have not submitted a certificate application.
        # 
        # *   **unknow**: The status is **unknown**.
        self.type = type
        # The file that you need to create on the DNS server when you use the file verification method. **The value of this parameter contains the file path and file name.**
        # 
        # >  This parameter is returned only when the value of the **Type** parameter is **domain_verify** and the value of the **ValidateType** parameter is **FILE**. The value domain_verify indicates that the verification of the domain name ownership is not complete, and the value FILE indicates that the file verification method is used.
        self.uri = uri
        # The verification method of the domain name ownership. Valid values:
        # 
        # *   **DNS**: DNS verification. If you use this method, you must add a TXT record to the DNS records of the domain name in the management platform of the domain name.
        # *   **FILE**: file verification. If you use this method, you must create a specified file on the DNS server.
        # 
        # >  This parameter is returned only when the value of the **Type** parameter is **domain_verify**. The value domain_verify indicates that the verification of the domain name ownership is not complete.
        self.validate_type = validate_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_id is not None:
            result['CertId'] = self.cert_id

        if self.certificate is not None:
            result['Certificate'] = self.certificate

        if self.content is not None:
            result['Content'] = self.content

        if self.domain is not None:
            result['Domain'] = self.domain

        if self.private_key is not None:
            result['PrivateKey'] = self.private_key

        if self.record_domain is not None:
            result['RecordDomain'] = self.record_domain

        if self.record_type is not None:
            result['RecordType'] = self.record_type

        if self.record_value is not None:
            result['RecordValue'] = self.record_value

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.type is not None:
            result['Type'] = self.type

        if self.uri is not None:
            result['Uri'] = self.uri

        if self.validate_type is not None:
            result['ValidateType'] = self.validate_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertId') is not None:
            self.cert_id = m.get('CertId')

        if m.get('Certificate') is not None:
            self.certificate = m.get('Certificate')

        if m.get('Content') is not None:
            self.content = m.get('Content')

        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('PrivateKey') is not None:
            self.private_key = m.get('PrivateKey')

        if m.get('RecordDomain') is not None:
            self.record_domain = m.get('RecordDomain')

        if m.get('RecordType') is not None:
            self.record_type = m.get('RecordType')

        if m.get('RecordValue') is not None:
            self.record_value = m.get('RecordValue')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        if m.get('Uri') is not None:
            self.uri = m.get('Uri')

        if m.get('ValidateType') is not None:
            self.validate_type = m.get('ValidateType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class UpdateInstanceRequest(DaraModel):
    def __init__(
        self,
        auto_reissue: str = None,
        certificate_name: str = None,
        city: str = None,
        company_id: int = None,
        contact_id_list: List[int] = None,
        country_code: str = None,
        csr: str = None,
        domain: str = None,
        generate_csr_method: str = None,
        instance_id: str = None,
        key_algorithm: str = None,
        province: str = None,
        resource_group_id: str = None,
        tags: List[main_models.UpdateInstanceRequestTags] = None,
        validation_method: str = None,
    ):
        self.auto_reissue = auto_reissue
        self.certificate_name = certificate_name
        self.city = city
        self.company_id = company_id
        self.contact_id_list = contact_id_list
        self.country_code = country_code
        self.csr = csr
        self.domain = domain
        self.generate_csr_method = generate_csr_method
        # This parameter is required.
        self.instance_id = instance_id
        self.key_algorithm = key_algorithm
        self.province = province
        self.resource_group_id = resource_group_id
        self.tags = tags
        self.validation_method = validation_method

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_reissue is not None:
            result['AutoReissue'] = self.auto_reissue

        if self.certificate_name is not None:
            result['CertificateName'] = self.certificate_name

        if self.city is not None:
            result['City'] = self.city

        if self.company_id is not None:
            result['CompanyId'] = self.company_id

        if self.contact_id_list is not None:
            result['ContactIdList'] = self.contact_id_list

        if self.country_code is not None:
            result['CountryCode'] = self.country_code

        if self.csr is not None:
            result['Csr'] = self.csr

        if self.domain is not None:
            result['Domain'] = self.domain

        if self.generate_csr_method is not None:
            result['GenerateCsrMethod'] = self.generate_csr_method

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.key_algorithm is not None:
            result['KeyAlgorithm'] = self.key_algorithm

        if self.province is not None:
            result['Province'] = self.province

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        if self.validation_method is not None:
            result['ValidationMethod'] = self.validation_method

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoReissue') is not None:
            self.auto_reissue = m.get('AutoReissue')

        if m.get('CertificateName') is not None:
            self.certificate_name = m.get('CertificateName')

        if m.get('City') is not None:
            self.city = m.get('City')

        if m.get('CompanyId') is not None:
            self.company_id = m.get('CompanyId')

        if m.get('ContactIdList') is not None:
            self.contact_id_list = m.get('ContactIdList')

        if m.get('CountryCode') is not None:
            self.country_code = m.get('CountryCode')

        if m.get('Csr') is not None:
            self.csr = m.get('Csr')

        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('GenerateCsrMethod') is not None:
            self.generate_csr_method = m.get('GenerateCsrMethod')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('KeyAlgorithm') is not None:
            self.key_algorithm = m.get('KeyAlgorithm')

        if m.get('Province') is not None:
            self.province = m.get('Province')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.UpdateInstanceRequestTags()
                self.tags.append(temp_model.from_map(k1))

        if m.get('ValidationMethod') is not None:
            self.validation_method = m.get('ValidationMethod')

        return self

class UpdateInstanceRequestTags(DaraModel):
    def __init__(
        self,
        tag_key: str = None,
        tag_value: str = None,
    ):
        self.tag_key = tag_key
        self.tag_value = tag_value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.tag_key is not None:
            result['TagKey'] = self.tag_key

        if self.tag_value is not None:
            result['TagValue'] = self.tag_value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('TagKey') is not None:
            self.tag_key = m.get('TagKey')

        if m.get('TagValue') is not None:
            self.tag_value = m.get('TagValue')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListUserCertificateOrderResponseBody(DaraModel):
    def __init__(
        self,
        certificate_order_list: List[main_models.ListUserCertificateOrderResponseBodyCertificateOrderList] = None,
        current_page: int = None,
        request_id: str = None,
        show_size: int = None,
        total_count: int = None,
    ):
        # The certificates and orders.
        self.certificate_order_list = certificate_order_list
        # The page number of the returned page.
        self.current_page = current_page
        # The ID of the request, which is used to locate and troubleshoot issues.
        self.request_id = request_id
        # The number of entries returned per page.
        self.show_size = show_size
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.certificate_order_list:
            for v1 in self.certificate_order_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['CertificateOrderList'] = []
        if self.certificate_order_list is not None:
            for k1 in self.certificate_order_list:
                result['CertificateOrderList'].append(k1.to_map() if k1 else None)

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.certificate_order_list = []
        if m.get('CertificateOrderList') is not None:
            for k1 in m.get('CertificateOrderList'):
                temp_model = main_models.ListUserCertificateOrderResponseBodyCertificateOrderList()
                self.certificate_order_list.append(temp_model.from_map(k1))

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListUserCertificateOrderResponseBodyCertificateOrderList(DaraModel):
    def __init__(
        self,
        algorithm: str = None,
        aliyun_order_id: int = None,
        buy_date: int = None,
        cert_end_time: int = None,
        cert_start_time: int = None,
        cert_type: str = None,
        certificate_id: int = None,
        city: str = None,
        common_name: str = None,
        country: str = None,
        domain: str = None,
        domain_count: int = None,
        domain_type: str = None,
        end_date: str = None,
        expired: bool = None,
        fingerprint: str = None,
        instance_id: str = None,
        issuer: str = None,
        name: str = None,
        order_id: int = None,
        org_name: str = None,
        partner_order_id: str = None,
        product_code: str = None,
        product_name: str = None,
        province: str = None,
        resource_group_id: str = None,
        root_brand: str = None,
        sans: str = None,
        serial_no: str = None,
        sha_2: str = None,
        source_type: str = None,
        start_date: str = None,
        status: str = None,
        trustee_status: str = None,
        upload: bool = None,
        wild_domain_count: int = None,
    ):
        # The algorithm. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.algorithm = algorithm
        # The ID of the Alibaba Cloud order. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.aliyun_order_id = aliyun_order_id
        # The time at which the order was placed. Unit: milliseconds. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.buy_date = buy_date
        # The time at which the certificate expires. Unit: milliseconds. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.cert_end_time = cert_end_time
        # The time at which the certificate starts to take effect. Unit: milliseconds. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.cert_start_time = cert_start_time
        # The type of the certificate. This parameter is returned only if OrderType is set to CPACK or BUY. Valid values:
        # 
        # *   **DV**: domain validated (DV) certificate
        # *   **EV**: extended validation (EV) certificate
        # *   **OV**: organization validated (OV) certificate **FREE**: free certificate, available only on the China site (aliyun.com)
        self.cert_type = cert_type
        # The ID of the certificate. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.certificate_id = certificate_id
        # The city in which the organization is located. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.city = city
        # The parent domain name of the certificate. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.common_name = common_name
        # The code of the country in which the organization is located. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.country = country
        # The domain name. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.domain = domain
        # The total number of domain names that can be bound to the certificate. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.domain_count = domain_count
        # The type of the domain name. This parameter is returned only if OrderType is set to CPACK or BUY. Valid values:
        # 
        # *   **ONE**: single domain name
        # *   **MULTIPLE**: multiple domain names
        # *   **WILDCARD**: single wildcard domain name
        # *   **M_WILDCARD**: multiple wildcard domain names
        # *   **MIX**: hybrid domain name
        self.domain_type = domain_type
        # The time at which the certificate expires. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.end_date = end_date
        # Indicates whether the certificate expires. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.expired = expired
        # The fingerprint of the certificate. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.fingerprint = fingerprint
        # The ID of the resource.
        self.instance_id = instance_id
        # The issuer of the certificate. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.issuer = issuer
        # The name of the certificate. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.name = name
        # The order ID. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.order_id = order_id
        # The name of the organization that is associated with the certificate. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.org_name = org_name
        # The ID of the third-party certificate authority (CA) order. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.partner_order_id = partner_order_id
        # The specification ID of the order. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.product_code = product_code
        # The specification name of the order. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.product_name = product_name
        # The province or autonomous region in which the organization is located. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.province = province
        # The ID of the resource group. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.resource_group_id = resource_group_id
        # The brand of the certificate. Valid values: WoSign, CFCA, DigiCert, and vTrus. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.root_brand = root_brand
        # All domain names that are bound to the certificate. Multiple domain names are separated by commas (,). This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.sans = sans
        # The serial number of the certificate. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.serial_no = serial_no
        # The SHA-2 value of the certificate. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.sha_2 = sha_2
        # The type of the order. This parameter is returned only if OrderType is set to CPACK or BUY. Valid values:
        # 
        # *   **cpack**: virtual resource order
        # *   **buy**: purchase order
        self.source_type = source_type
        # The time at which the certificate starts to take effect. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.start_date = start_date
        # The certificate status of the order. This parameter is returned only if OrderType is set to CPACK or BUY. Valid values:
        # 
        # *   **PAYED**: pending application
        # *   **CHECKING**: reviewing
        # *   **CHECKED_FAIL**: review failed
        # *   **ISSUED**: issued
        # *   **WILLEXPIRED**: about to expire
        # *   **EXPIRED**: expired
        # *   **NOTACTIVATED**: not activated
        # *   **REVOKED**: revoked
        self.status = status
        # The hosting status of the certificate. This parameter is returned only if OrderType is set to CPACK or BUY. Valid values:
        # 
        # *   **unTrustee**: not hosted
        # *   **trustee**: hosted
        self.trustee_status = trustee_status
        # Indicates whether the certificate is an uploaded certificate. This parameter is returned only if OrderType is set to CERT or UPLOAD.
        self.upload = upload
        # The number of wildcard domain names that can be bound to the certificate. This parameter is returned only if OrderType is set to CPACK or BUY.
        self.wild_domain_count = wild_domain_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.aliyun_order_id is not None:
            result['AliyunOrderId'] = self.aliyun_order_id

        if self.buy_date is not None:
            result['BuyDate'] = self.buy_date

        if self.cert_end_time is not None:
            result['CertEndTime'] = self.cert_end_time

        if self.cert_start_time is not None:
            result['CertStartTime'] = self.cert_start_time

        if self.cert_type is not None:
            result['CertType'] = self.cert_type

        if self.certificate_id is not None:
            result['CertificateId'] = self.certificate_id

        if self.city is not None:
            result['City'] = self.city

        if self.common_name is not None:
            result['CommonName'] = self.common_name

        if self.country is not None:
            result['Country'] = self.country

        if self.domain is not None:
            result['Domain'] = self.domain

        if self.domain_count is not None:
            result['DomainCount'] = self.domain_count

        if self.domain_type is not None:
            result['DomainType'] = self.domain_type

        if self.end_date is not None:
            result['EndDate'] = self.end_date

        if self.expired is not None:
            result['Expired'] = self.expired

        if self.fingerprint is not None:
            result['Fingerprint'] = self.fingerprint

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.issuer is not None:
            result['Issuer'] = self.issuer

        if self.name is not None:
            result['Name'] = self.name

        if self.order_id is not None:
            result['OrderId'] = self.order_id

        if self.org_name is not None:
            result['OrgName'] = self.org_name

        if self.partner_order_id is not None:
            result['PartnerOrderId'] = self.partner_order_id

        if self.product_code is not None:
            result['ProductCode'] = self.product_code

        if self.product_name is not None:
            result['ProductName'] = self.product_name

        if self.province is not None:
            result['Province'] = self.province

        if self.resource_group_id is not None:
            result['ResourceGroupId'] = self.resource_group_id

        if self.root_brand is not None:
            result['RootBrand'] = self.root_brand

        if self.sans is not None:
            result['Sans'] = self.sans

        if self.serial_no is not None:
            result['SerialNo'] = self.serial_no

        if self.sha_2 is not None:
            result['Sha2'] = self.sha_2

        if self.source_type is not None:
            result['SourceType'] = self.source_type

        if self.start_date is not None:
            result['StartDate'] = self.start_date

        if self.status is not None:
            result['Status'] = self.status

        if self.trustee_status is not None:
            result['TrusteeStatus'] = self.trustee_status

        if self.upload is not None:
            result['Upload'] = self.upload

        if self.wild_domain_count is not None:
            result['WildDomainCount'] = self.wild_domain_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('AliyunOrderId') is not None:
            self.aliyun_order_id = m.get('AliyunOrderId')

        if m.get('BuyDate') is not None:
            self.buy_date = m.get('BuyDate')

        if m.get('CertEndTime') is not None:
            self.cert_end_time = m.get('CertEndTime')

        if m.get('CertStartTime') is not None:
            self.cert_start_time = m.get('CertStartTime')

        if m.get('CertType') is not None:
            self.cert_type = m.get('CertType')

        if m.get('CertificateId') is not None:
            self.certificate_id = m.get('CertificateId')

        if m.get('City') is not None:
            self.city = m.get('City')

        if m.get('CommonName') is not None:
            self.common_name = m.get('CommonName')

        if m.get('Country') is not None:
            self.country = m.get('Country')

        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('DomainCount') is not None:
            self.domain_count = m.get('DomainCount')

        if m.get('DomainType') is not None:
            self.domain_type = m.get('DomainType')

        if m.get('EndDate') is not None:
            self.end_date = m.get('EndDate')

        if m.get('Expired') is not None:
            self.expired = m.get('Expired')

        if m.get('Fingerprint') is not None:
            self.fingerprint = m.get('Fingerprint')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Issuer') is not None:
            self.issuer = m.get('Issuer')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('OrderId') is not None:
            self.order_id = m.get('OrderId')

        if m.get('OrgName') is not None:
            self.org_name = m.get('OrgName')

        if m.get('PartnerOrderId') is not None:
            self.partner_order_id = m.get('PartnerOrderId')

        if m.get('ProductCode') is not None:
            self.product_code = m.get('ProductCode')

        if m.get('ProductName') is not None:
            self.product_name = m.get('ProductName')

        if m.get('Province') is not None:
            self.province = m.get('Province')

        if m.get('ResourceGroupId') is not None:
            self.resource_group_id = m.get('ResourceGroupId')

        if m.get('RootBrand') is not None:
            self.root_brand = m.get('RootBrand')

        if m.get('Sans') is not None:
            self.sans = m.get('Sans')

        if m.get('SerialNo') is not None:
            self.serial_no = m.get('SerialNo')

        if m.get('Sha2') is not None:
            self.sha_2 = m.get('Sha2')

        if m.get('SourceType') is not None:
            self.source_type = m.get('SourceType')

        if m.get('StartDate') is not None:
            self.start_date = m.get('StartDate')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('TrusteeStatus') is not None:
            self.trustee_status = m.get('TrusteeStatus')

        if m.get('Upload') is not None:
            self.upload = m.get('Upload')

        if m.get('WildDomainCount') is not None:
            self.wild_domain_count = m.get('WildDomainCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribeDeploymentJobRequest(DaraModel):
    def __init__(
        self,
        job_id: int = None,
    ):
        # The ID of the deployment job. The **ID** of the job is returned after you call the [CreateDeploymentJob](https://help.aliyun.com/document_detail/2712234.html) operation. You can also call the [ListDeploymentJob](https://help.aliyun.com/document_detail/2712223.html) operation to obtain the ID.
        # 
        # This parameter is required.
        self.job_id = job_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.job_id is not None:
            result['JobId'] = self.job_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('JobId') is not None:
            self.job_id = m.get('JobId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListWorkerResourceResponseBody(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        data: List[main_models.ListWorkerResourceResponseBodyData] = None,
        request_id: str = None,
        show_size: int = None,
        total: int = None,
    ):
        # The page number. Default value: 1.
        self.current_page = current_page
        # The response parameters.
        self.data = data
        # The request ID.
        self.request_id = request_id
        # The number of entries per page. Default value: **50**.
        self.show_size = show_size
        # The total number of entries returned.
        self.total = total

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.ListWorkerResourceResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class ListWorkerResourceResponseBodyData(DaraModel):
    def __init__(
        self,
        cert_domain: str = None,
        cert_id: int = None,
        cert_instance_id: str = None,
        cert_name: str = None,
        cloud_name: str = None,
        cloud_product: str = None,
        cloud_region: str = None,
        default_resource: bool = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        id: int = None,
        instance_id: str = None,
        job_id: int = None,
        listener_id: str = None,
        namespace_id: str = None,
        order_id: int = None,
        port: int = None,
        region_id: str = None,
        resource_cert_id: int = None,
        resource_domain: str = None,
        resource_id: int = None,
        status: str = None,
        user_id: int = None,
    ):
        # The domain name bound to the certificate in the worker task.
        self.cert_domain = cert_domain
        # The ID of the certificate in the worker task.
        self.cert_id = cert_id
        # The instance ID of the certificate in the worker task.
        self.cert_instance_id = cert_instance_id
        # The name of the certificate in the worker task.
        self.cert_name = cert_name
        # The cloud service provider to which the cloud resource in the worker task belongs.
        # 
        # >  This parameter is not returned if you deploy certificates to Alibaba Cloud services.
        self.cloud_name = cloud_name
        # The cloud service to which the cloud resource in the worker task belongs. Valid values:
        # 
        # *   **CDN**: Alibaba Cloud CDN (CDN). This value is supported only at the China site (aliyun.com).
        # *   **SLB**: Classic Load Balancer (CLB). This value is supported only at the China site (aliyun.com).
        # *   **DCDN**: Dynamic Content Delivery Network (DCDN). This value is supported only at the China site (aliyun.com).
        # *   **DDOS**: Anti-DDoS. This value is supported only at the China site (aliyun.com).
        # *   **LIVE**: ApsaraVideo Live. This value is supported only at the China site (aliyun.com).
        # *   **webHosting**: Cloud Web Hosting. This value is supported only at the China site (aliyun.com).
        # *   **VOD**: ApsaraVideo VOD. This value is supported only at the China site (aliyun.com).
        # *   **CR**: Container Registry. This value is supported only at the China site (aliyun.com).
        # *   **ALB**: Application Load Balancer (ALB).
        # *   **APIGateway**: API Gateway.
        # *   **FC**: Function Compute.
        # *   **GA**: Global Accelerator (GA).
        # *   **MSE**: Microservices Engine (MSE).
        # *   **NLB**: Network Load Balancer (NLB).
        # *   **OSS**: Object Storage Service (OSS).
        # *   **SAE**: Serverless App Engine (SAE).
        # *   **TencentCDN**: Tencent Cloud Content Delivery Network (CDN).
        # *   **WAF**: Web Application Firewall (WAF).
        self.cloud_product = cloud_product
        # The original region ID of the cloud resource in the worker task. The value is the region ID defined by the cloud service provider. This parameter is required only when you deploy certificates to services of multiple clouds.
        self.cloud_region = cloud_region
        # Indicates whether the cloud resource in the worker task is the default resource. Valid values:
        # 
        # *   **true**
        # *   **false**
        # 
        # >  This parameter is returned only when the value of CloudProduct is SLB, NLB, ALB, or GA.
        self.default_resource = default_resource
        # The time when the worker task was created. The time is a timestamp in seconds.
        self.gmt_create = gmt_create
        # The time when the worker task was last modified. The time is a timestamp in seconds.
        self.gmt_modified = gmt_modified
        # The ID of the worker task.
        self.id = id
        # The ID of the cloud resource in the worker task.
        # 
        # >  This parameter is returned only when the value of CloudProduct is SLB, NLB, ALB, or GA.
        self.instance_id = instance_id
        # The ID of the deployment task to which the worker task belongs.
        self.job_id = job_id
        # The listener ID of the cloud resource in the worker task.
        # 
        # >  This parameter is returned only when the value of CloudProduct is SLB, NLB, ALB, or GA.
        self.listener_id = listener_id
        # The ID of the namespace in SAE. This parameter is returned only if you deploy certificates to SAE.
        self.namespace_id = namespace_id
        # The order ID of the worker task, which is the same as the order ID of the certificate.
        # 
        # >  If the CertId parameter is returned, this parameter is not returned.
        self.order_id = order_id
        # The listening port of the cloud resource in the worker task.
        # 
        # >  This parameter is returned only when the value of CloudProduct is SLB, NLB, ALB, or GA.
        self.port = port
        # The region ID of the cloud resource in the worker task.
        self.region_id = region_id
        # The ID of the certificate that was originally bound to the cloud resource in the worker task.
        self.resource_cert_id = resource_cert_id
        # The domain name that was originally bound to the cloud resource in the worker task.
        self.resource_domain = resource_domain
        # The ID of the cloud resource in the worker task.
        self.resource_id = resource_id
        # The status of the worker task. Valid values:
        # 
        # *   **editing**
        # *   **pending**
        # *   **scheduling**
        # *   **processing**
        # *   **error**
        # *   **success**
        # *   **rollback**
        # *   **rollback_success**
        # *   **rollback_error**
        self.status = status
        # The ID of the Alibaba Cloud account to which the worker task belongs.
        self.user_id = user_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cert_domain is not None:
            result['CertDomain'] = self.cert_domain

        if self.cert_id is not None:
            result['CertId'] = self.cert_id

        if self.cert_instance_id is not None:
            result['CertInstanceId'] = self.cert_instance_id

        if self.cert_name is not None:
            result['CertName'] = self.cert_name

        if self.cloud_name is not None:
            result['CloudName'] = self.cloud_name

        if self.cloud_product is not None:
            result['CloudProduct'] = self.cloud_product

        if self.cloud_region is not None:
            result['CloudRegion'] = self.cloud_region

        if self.default_resource is not None:
            result['DefaultResource'] = self.default_resource

        if self.gmt_create is not None:
            result['GmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['GmtModified'] = self.gmt_modified

        if self.id is not None:
            result['Id'] = self.id

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.job_id is not None:
            result['JobId'] = self.job_id

        if self.listener_id is not None:
            result['ListenerId'] = self.listener_id

        if self.namespace_id is not None:
            result['NamespaceId'] = self.namespace_id

        if self.order_id is not None:
            result['OrderId'] = self.order_id

        if self.port is not None:
            result['Port'] = self.port

        if self.region_id is not None:
            result['RegionId'] = self.region_id

        if self.resource_cert_id is not None:
            result['ResourceCertId'] = self.resource_cert_id

        if self.resource_domain is not None:
            result['ResourceDomain'] = self.resource_domain

        if self.resource_id is not None:
            result['ResourceId'] = self.resource_id

        if self.status is not None:
            result['Status'] = self.status

        if self.user_id is not None:
            result['UserId'] = self.user_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CertDomain') is not None:
            self.cert_domain = m.get('CertDomain')

        if m.get('CertId') is not None:
            self.cert_id = m.get('CertId')

        if m.get('CertInstanceId') is not None:
            self.cert_instance_id = m.get('CertInstanceId')

        if m.get('CertName') is not None:
            self.cert_name = m.get('CertName')

        if m.get('CloudName') is not None:
            self.cloud_name = m.get('CloudName')

        if m.get('CloudProduct') is not None:
            self.cloud_product = m.get('CloudProduct')

        if m.get('CloudRegion') is not None:
            self.cloud_region = m.get('CloudRegion')

        if m.get('DefaultResource') is not None:
            self.default_resource = m.get('DefaultResource')

        if m.get('GmtCreate') is not None:
            self.gmt_create = m.get('GmtCreate')

        if m.get('GmtModified') is not None:
            self.gmt_modified = m.get('GmtModified')

        if m.get('Id') is not None:
            self.id = m.get('Id')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('JobId') is not None:
            self.job_id = m.get('JobId')

        if m.get('ListenerId') is not None:
            self.listener_id = m.get('ListenerId')

        if m.get('NamespaceId') is not None:
            self.namespace_id = m.get('NamespaceId')

        if m.get('OrderId') is not None:
            self.order_id = m.get('OrderId')

        if m.get('Port') is not None:
            self.port = m.get('Port')

        if m.get('RegionId') is not None:
            self.region_id = m.get('RegionId')

        if m.get('ResourceCertId') is not None:
            self.resource_cert_id = m.get('ResourceCertId')

        if m.get('ResourceDomain') is not None:
            self.resource_domain = m.get('ResourceDomain')

        if m.get('ResourceId') is not None:
            self.resource_id = m.get('ResourceId')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class RenewCertificateOrderForPackageRequestRequest(DaraModel):
    def __init__(
        self,
        csr: str = None,
        order_id: int = None,
        tags: List[main_models.RenewCertificateOrderForPackageRequestRequestTags] = None,
    ):
        # The content of the certificate signing request (CSR) file that is manually generated for the domain name by using OpenSSL or Keytool. The key algorithm in the CSR file must be Rivest-Shamir-Adleman (RSA) or elliptic-curve cryptography (ECC), and the key length of the RSA algorithm must be greater than or equal to 2,048 characters. For more information about how to create a CSR file, see [How do I create a CSR file?](https://help.aliyun.com/document_detail/42218.html)
        # 
        # If you do not specify this parameter, Certificate Management Service automatically generates a CSR file for the domain name in the certificate application order that you want to renew.
        # 
        # A CSR file contains the information about your server and company. When you apply for a certificate, you must submit the CSR file to the CA. The CA signs the CSR file by using the private key of the root certificate and generates a public key file to issue your certificate.
        # 
        # >  The **CN** field in the CSR file specifies the domain name that is bound to the certificate.
        self.csr = csr
        # The ID of the certificate application order that you want to renew.
        # 
        # >  After you call the [CreateCertificateForPackageRequest](https://help.aliyun.com/document_detail/455296.html), [CreateCertificateRequest](https://help.aliyun.com/document_detail/455292.html), or [CreateCertificateWithCsrRequest](https://help.aliyun.com/document_detail/455801.html) operation to submit a certificate application, you can obtain the ID of the certificate application order from the **OrderId** response parameter. You can also call the [ListUserCertificateOrder](https://help.aliyun.com/document_detail/455804.html) operation to obtain the order ID.
        # 
        # This parameter is required.
        self.order_id = order_id
        # The tags.
        self.tags = tags

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.csr is not None:
            result['Csr'] = self.csr

        if self.order_id is not None:
            result['OrderId'] = self.order_id

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Csr') is not None:
            self.csr = m.get('Csr')

        if m.get('OrderId') is not None:
            self.order_id = m.get('OrderId')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.RenewCertificateOrderForPackageRequestRequestTags()
                self.tags.append(temp_model.from_map(k1))

        return self

class RenewCertificateOrderForPackageRequestRequestTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The tag key. You can specify at most 20 tag keys. The tag key cannot be an empty string.
        # 
        # A tag key can be up to 128 characters in length. It cannot start with aliyun or acs:, and cannot contain http:// or https://.
        self.key = key
        # The value of the resource tag. A maximum of 20 tag values can be entered. If this value needs to be passed in, an empty string can be entered.
        # 
        # A maximum of 128 characters are supported, it cannot start with \\"aliyun\\" or \\"acs:\\", and it cannot contain \\"http://\\" or \\"https://\\".
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListDeploymentJobCertResponseBody(DaraModel):
    def __init__(
        self,
        data: List[main_models.ListDeploymentJobCertResponseBodyData] = None,
        request_id: str = None,
    ):
        # The response parameters.
        self.data = data
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.ListDeploymentJobCertResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class ListDeploymentJobCertResponseBodyData(DaraModel):
    def __init__(
        self,
        algorithm: str = None,
        cert_id: int = None,
        cert_instance_id: str = None,
        cert_name: str = None,
        cert_order_type: str = None,
        cert_type: str = None,
        common_name: str = None,
        is_trustee: bool = None,
        month: int = None,
        not_after_time: int = None,
        not_before_time: int = None,
        order_id: int = None,
        sans: List[str] = None,
        status_code: str = None,
    ):
        # The algorithm of the certificate public key.
        self.algorithm = algorithm
        # The ID of the certificate.
        self.cert_id = cert_id
        # The instance ID of the certificate.
        self.cert_instance_id = cert_instance_id
        # The name of the certificate.
        self.cert_name = cert_name
        # The type of the certificate order. Valid values:
        # 
        # *   **upload**: uploaded certificate.
        # *   **buy**: purchased certificate.
        # *   **free**: free certificate. This value is available only on the China site (aliyun.com).
        self.cert_order_type = cert_order_type
        # The type of the certificate.
        self.cert_type = cert_type
        # The common name of the certificate.
        self.common_name = common_name
        # Indicates whether the certificate is hosted. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.is_trustee = is_trustee
        # The month in which the certificate is applied for.
        self.month = month
        # The end time of the validity period of the certificate. The value is a timestamp in seconds.
        self.not_after_time = not_after_time
        # The start time of the validity period of the certificate. The value is a timestamp in seconds.
        self.not_before_time = not_before_time
        # The ID of the certificate order.
        # 
        # >  If CertId is returned, this parameter is not returned.
        self.order_id = order_id
        # The subject alternative name (SAN) extensions of the certificate.
        self.sans = sans
        # The status code of the certificate. Valid values:
        # 
        # *   **payed**: paid and pending application
        # *   **checking**: being validated
        # *   **checkedFail**: validation failed
        # *   **revoked**: revoked
        # *   **revokeChecking**: revocation request being validated
        # *   **issued**: issued (excluding hosted certificates that are issued, certificates that are about to expire, expired certificates, and uploaded certificates)
        # *   **trustee**: hosted and issued
        # *   **upload**: uploaded (excluding certificates that are about to expire and expired certificates)
        # *   **willExpired**: about to expire (including certificates issued by using the Certificate Management Service console and uploaded certificates)
        # *   **expired**: expired (including certificates issued by using the Certificate Management Service console and uploaded certificates)
        # *   **validity**: valid (including certificates that are not expired or revoked)
        # *   **refund**: refunded
        # *   **closed**: closed
        self.status_code = status_code

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.cert_id is not None:
            result['CertId'] = self.cert_id

        if self.cert_instance_id is not None:
            result['CertInstanceId'] = self.cert_instance_id

        if self.cert_name is not None:
            result['CertName'] = self.cert_name

        if self.cert_order_type is not None:
            result['CertOrderType'] = self.cert_order_type

        if self.cert_type is not None:
            result['CertType'] = self.cert_type

        if self.common_name is not None:
            result['CommonName'] = self.common_name

        if self.is_trustee is not None:
            result['IsTrustee'] = self.is_trustee

        if self.month is not None:
            result['Month'] = self.month

        if self.not_after_time is not None:
            result['NotAfterTime'] = self.not_after_time

        if self.not_before_time is not None:
            result['NotBeforeTime'] = self.not_before_time

        if self.order_id is not None:
            result['OrderId'] = self.order_id

        if self.sans is not None:
            result['Sans'] = self.sans

        if self.status_code is not None:
            result['StatusCode'] = self.status_code

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('CertId') is not None:
            self.cert_id = m.get('CertId')

        if m.get('CertInstanceId') is not None:
            self.cert_instance_id = m.get('CertInstanceId')

        if m.get('CertName') is not None:
            self.cert_name = m.get('CertName')

        if m.get('CertOrderType') is not None:
            self.cert_order_type = m.get('CertOrderType')

        if m.get('CertType') is not None:
            self.cert_type = m.get('CertType')

        if m.get('CommonName') is not None:
            self.common_name = m.get('CommonName')

        if m.get('IsTrustee') is not None:
            self.is_trustee = m.get('IsTrustee')

        if m.get('Month') is not None:
            self.month = m.get('Month')

        if m.get('NotAfterTime') is not None:
            self.not_after_time = m.get('NotAfterTime')

        if m.get('NotBeforeTime') is not None:
            self.not_before_time = m.get('NotBeforeTime')

        if m.get('OrderId') is not None:
            self.order_id = m.get('OrderId')

        if m.get('Sans') is not None:
            self.sans = m.get('Sans')

        if m.get('StatusCode') is not None:
            self.status_code = m.get('StatusCode')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListCertificatesResponseBody(DaraModel):
    def __init__(
        self,
        certificate_list: List[main_models.ListCertificatesResponseBodyCertificateList] = None,
        current_page: int = None,
        request_id: str = None,
        show_size: int = None,
        total_count: int = None,
    ):
        self.certificate_list = certificate_list
        self.current_page = current_page
        self.request_id = request_id
        self.show_size = show_size
        self.total_count = total_count

    def validate(self):
        if self.certificate_list:
            for v1 in self.certificate_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['CertificateList'] = []
        if self.certificate_list is not None:
            for k1 in self.certificate_list:
                result['CertificateList'].append(k1.to_map() if k1 else None)

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.certificate_list = []
        if m.get('CertificateList') is not None:
            for k1 in m.get('CertificateList'):
                temp_model = main_models.ListCertificatesResponseBodyCertificateList()
                self.certificate_list.append(temp_model.from_map(k1))

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListCertificatesResponseBodyCertificateList(DaraModel):
    def __init__(
        self,
        algorithm: str = None,
        cert_identifier: str = None,
        certificate_id: str = None,
        certificate_name: str = None,
        certificate_source: str = None,
        certificate_status: str = None,
        common_name: str = None,
        domain: str = None,
        exist_private_key: bool = None,
        finger_print: str = None,
        instance_id: str = None,
        issuer: str = None,
        key_size: int = None,
        not_after: int = None,
        not_before: int = None,
        serial: str = None,
        subject_alternative_names: List[str] = None,
        using_product_list: List[str] = None,
    ):
        self.algorithm = algorithm
        self.cert_identifier = cert_identifier
        self.certificate_id = certificate_id
        self.certificate_name = certificate_name
        self.certificate_source = certificate_source
        self.certificate_status = certificate_status
        self.common_name = common_name
        self.domain = domain
        self.exist_private_key = exist_private_key
        self.finger_print = finger_print
        self.instance_id = instance_id
        self.issuer = issuer
        self.key_size = key_size
        self.not_after = not_after
        self.not_before = not_before
        self.serial = serial
        self.subject_alternative_names = subject_alternative_names
        self.using_product_list = using_product_list

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.cert_identifier is not None:
            result['CertIdentifier'] = self.cert_identifier

        if self.certificate_id is not None:
            result['CertificateId'] = self.certificate_id

        if self.certificate_name is not None:
            result['CertificateName'] = self.certificate_name

        if self.certificate_source is not None:
            result['CertificateSource'] = self.certificate_source

        if self.certificate_status is not None:
            result['CertificateStatus'] = self.certificate_status

        if self.common_name is not None:
            result['CommonName'] = self.common_name

        if self.domain is not None:
            result['Domain'] = self.domain

        if self.exist_private_key is not None:
            result['ExistPrivateKey'] = self.exist_private_key

        if self.finger_print is not None:
            result['FingerPrint'] = self.finger_print

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.issuer is not None:
            result['Issuer'] = self.issuer

        if self.key_size is not None:
            result['KeySize'] = self.key_size

        if self.not_after is not None:
            result['NotAfter'] = self.not_after

        if self.not_before is not None:
            result['NotBefore'] = self.not_before

        if self.serial is not None:
            result['Serial'] = self.serial

        if self.subject_alternative_names is not None:
            result['SubjectAlternativeNames'] = self.subject_alternative_names

        if self.using_product_list is not None:
            result['UsingProductList'] = self.using_product_list

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('CertIdentifier') is not None:
            self.cert_identifier = m.get('CertIdentifier')

        if m.get('CertificateId') is not None:
            self.certificate_id = m.get('CertificateId')

        if m.get('CertificateName') is not None:
            self.certificate_name = m.get('CertificateName')

        if m.get('CertificateSource') is not None:
            self.certificate_source = m.get('CertificateSource')

        if m.get('CertificateStatus') is not None:
            self.certificate_status = m.get('CertificateStatus')

        if m.get('CommonName') is not None:
            self.common_name = m.get('CommonName')

        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('ExistPrivateKey') is not None:
            self.exist_private_key = m.get('ExistPrivateKey')

        if m.get('FingerPrint') is not None:
            self.finger_print = m.get('FingerPrint')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Issuer') is not None:
            self.issuer = m.get('Issuer')

        if m.get('KeySize') is not None:
            self.key_size = m.get('KeySize')

        if m.get('NotAfter') is not None:
            self.not_after = m.get('NotAfter')

        if m.get('NotBefore') is not None:
            self.not_before = m.get('NotBefore')

        if m.get('Serial') is not None:
            self.serial = m.get('Serial')

        if m.get('SubjectAlternativeNames') is not None:
            self.subject_alternative_names = m.get('SubjectAlternativeNames')

        if m.get('UsingProductList') is not None:
            self.using_product_list = m.get('UsingProductList')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DecryptRequest(DaraModel):
    def __init__(
        self,
        algorithm: str = None,
        cert_identifier: str = None,
        ciphertext_blob: str = None,
        custom_identifier: str = None,
        message_type: str = None,
        warehouse_id: int = None,
    ):
        # The encryption algorithm. Valid values:
        # 
        # *   **RSAES_OAEP_SHA_1**
        # *   **RSAES_OAEP_SHA_256**
        # *   **SM2PKE**
        # 
        # This parameter is required.
        self.algorithm = algorithm
        # The unique identifier of the certificate. You can call the [ListCert](https://help.aliyun.com/document_detail/455806.html) operation to query the identifier.
        # 
        # *   If the certificate is an SSL certificate, the value of this parameter must be in the {Certificate ID}-cn-hangzhou format.
        # *   If the certificate is a private certificate, the value of this parameter must be the value of the Identifier field for the private certificate.
        self.cert_identifier = cert_identifier
        # The data that you want to decrypt. The value is encoded in Base64.
        # 
        # This parameter is required.
        self.ciphertext_blob = ciphertext_blob
        self.custom_identifier = custom_identifier
        # The value type of the Message parameter. Valid values:
        # 
        # *   RAW: The returned result is raw data encoded in UTF-8.
        # *   Base64: The returned result is Base64-encoded data. This is the default value.
        self.message_type = message_type
        self.warehouse_id = warehouse_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.cert_identifier is not None:
            result['CertIdentifier'] = self.cert_identifier

        if self.ciphertext_blob is not None:
            result['CiphertextBlob'] = self.ciphertext_blob

        if self.custom_identifier is not None:
            result['CustomIdentifier'] = self.custom_identifier

        if self.message_type is not None:
            result['MessageType'] = self.message_type

        if self.warehouse_id is not None:
            result['WarehouseId'] = self.warehouse_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('CertIdentifier') is not None:
            self.cert_identifier = m.get('CertIdentifier')

        if m.get('CiphertextBlob') is not None:
            self.ciphertext_blob = m.get('CiphertextBlob')

        if m.get('CustomIdentifier') is not None:
            self.custom_identifier = m.get('CustomIdentifier')

        if m.get('MessageType') is not None:
            self.message_type = m.get('MessageType')

        if m.get('WarehouseId') is not None:
            self.warehouse_id = m.get('WarehouseId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class DescribeCloudResourceStatusResponseBody(DaraModel):
    def __init__(
        self,
        data: List[main_models.DescribeCloudResourceStatusResponseBodyData] = None,
        request_id: str = None,
    ):
        # The response parameters.
        self.data = data
        # The request ID.
        self.request_id = request_id

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.DescribeCloudResourceStatusResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        return self

class DescribeCloudResourceStatusResponseBodyData(DaraModel):
    def __init__(
        self,
        cloud_name: str = None,
        cloud_product: str = None,
        total_count: int = None,
    ):
        # The cloud service provider.
        self.cloud_name = cloud_name
        # The cloud service.
        self.cloud_product = cloud_product
        # The total number of cloud resources on which certificates are deployed.
        self.total_count = total_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cloud_name is not None:
            result['CloudName'] = self.cloud_name

        if self.cloud_product is not None:
            result['CloudProduct'] = self.cloud_product

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CloudName') is not None:
            self.cloud_name = m.get('CloudName')

        if m.get('CloudProduct') is not None:
            self.cloud_product = m.get('CloudProduct')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateWHClientCertificateRequest(DaraModel):
    def __init__(
        self,
        after_time: int = None,
        algorithm: str = None,
        before_time: int = None,
        common_name: str = None,
        country: str = None,
        csr: str = None,
        days: int = None,
        immediately: int = None,
        locality: str = None,
        months: int = None,
        organization: str = None,
        organization_unit: str = None,
        parent_identifier: str = None,
        san_type: int = None,
        san_value: str = None,
        state: str = None,
        years: int = None,
    ):
        self.after_time = after_time
        self.algorithm = algorithm
        self.before_time = before_time
        self.common_name = common_name
        self.country = country
        self.csr = csr
        self.days = days
        self.immediately = immediately
        self.locality = locality
        self.months = months
        self.organization = organization
        self.organization_unit = organization_unit
        # This parameter is required.
        self.parent_identifier = parent_identifier
        self.san_type = san_type
        self.san_value = san_value
        self.state = state
        self.years = years

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.after_time is not None:
            result['AfterTime'] = self.after_time

        if self.algorithm is not None:
            result['Algorithm'] = self.algorithm

        if self.before_time is not None:
            result['BeforeTime'] = self.before_time

        if self.common_name is not None:
            result['CommonName'] = self.common_name

        if self.country is not None:
            result['Country'] = self.country

        if self.csr is not None:
            result['Csr'] = self.csr

        if self.days is not None:
            result['Days'] = self.days

        if self.immediately is not None:
            result['Immediately'] = self.immediately

        if self.locality is not None:
            result['Locality'] = self.locality

        if self.months is not None:
            result['Months'] = self.months

        if self.organization is not None:
            result['Organization'] = self.organization

        if self.organization_unit is not None:
            result['OrganizationUnit'] = self.organization_unit

        if self.parent_identifier is not None:
            result['ParentIdentifier'] = self.parent_identifier

        if self.san_type is not None:
            result['SanType'] = self.san_type

        if self.san_value is not None:
            result['SanValue'] = self.san_value

        if self.state is not None:
            result['State'] = self.state

        if self.years is not None:
            result['Years'] = self.years

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AfterTime') is not None:
            self.after_time = m.get('AfterTime')

        if m.get('Algorithm') is not None:
            self.algorithm = m.get('Algorithm')

        if m.get('BeforeTime') is not None:
            self.before_time = m.get('BeforeTime')

        if m.get('CommonName') is not None:
            self.common_name = m.get('CommonName')

        if m.get('Country') is not None:
            self.country = m.get('Country')

        if m.get('Csr') is not None:
            self.csr = m.get('Csr')

        if m.get('Days') is not None:
            self.days = m.get('Days')

        if m.get('Immediately') is not None:
            self.immediately = m.get('Immediately')

        if m.get('Locality') is not None:
            self.locality = m.get('Locality')

        if m.get('Months') is not None:
            self.months = m.get('Months')

        if m.get('Organization') is not None:
            self.organization = m.get('Organization')

        if m.get('OrganizationUnit') is not None:
            self.organization_unit = m.get('OrganizationUnit')

        if m.get('ParentIdentifier') is not None:
            self.parent_identifier = m.get('ParentIdentifier')

        if m.get('SanType') is not None:
            self.san_type = m.get('SanType')

        if m.get('SanValue') is not None:
            self.san_value = m.get('SanValue')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('Years') is not None:
            self.years = m.get('Years')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListCertWarehouseResponseBody(DaraModel):
    def __init__(
        self,
        cert_warehouse_list: List[main_models.ListCertWarehouseResponseBodyCertWarehouseList] = None,
        current_page: int = None,
        request_id: str = None,
        show_size: int = None,
        total_count: int = None,
    ):
        # The certificate application repositories.
        self.cert_warehouse_list = cert_warehouse_list
        # The page number of the returned page. Default value: 1.
        self.current_page = current_page
        # The ID of the request.
        self.request_id = request_id
        # The number of entries returned per page. Default value: 50.
        self.show_size = show_size
        # The total number of entries returned.
        self.total_count = total_count

    def validate(self):
        if self.cert_warehouse_list:
            for v1 in self.cert_warehouse_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['CertWarehouseList'] = []
        if self.cert_warehouse_list is not None:
            for k1 in self.cert_warehouse_list:
                result['CertWarehouseList'].append(k1.to_map() if k1 else None)

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.cert_warehouse_list = []
        if m.get('CertWarehouseList') is not None:
            for k1 in m.get('CertWarehouseList'):
                temp_model = main_models.ListCertWarehouseResponseBodyCertWarehouseList()
                self.cert_warehouse_list.append(temp_model.from_map(k1))

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListCertWarehouseResponseBodyCertWarehouseList(DaraModel):
    def __init__(
        self,
        end_time: int = None,
        instance_id: str = None,
        is_expired: bool = None,
        name: str = None,
        pca_instance_id: str = None,
        qps: int = None,
        type: str = None,
        wh_id: int = None,
    ):
        # The timestamp when the certificate application repository expires. Unit: milliseconds.
        self.end_time = end_time
        # The instance ID of the certificate application repository.
        self.instance_id = instance_id
        # Indicates whether the certificate application repository has expired. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.is_expired = is_expired
        # The name of the certificate application repository.
        self.name = name
        # The instance ID of the private CA.
        self.pca_instance_id = pca_instance_id
        # The queries per second (QPS).
        self.qps = qps
        # The type of the certificate application repository. Valid values:
        # 
        # *   **ssl**: certificate application repository of SSL certificates
        # *   **uploadPCA**: certificate application repository of uploaded private certificates
        # *   **free**: certificate application repository of free certificates, available only on the China site (aliyun.com)
        # *   **aliyunPCA**: certificate application repository of private certificates purchased from Alibaba Cloud Private Certificate Authority (PCA), available only on the China site (aliyun.com)
        # *   **disable**: disabled certificate application repository
        self.type = type
        # The ID of the certificate application repository.
        self.wh_id = wh_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end_time is not None:
            result['EndTime'] = self.end_time

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.is_expired is not None:
            result['IsExpired'] = self.is_expired

        if self.name is not None:
            result['Name'] = self.name

        if self.pca_instance_id is not None:
            result['PcaInstanceId'] = self.pca_instance_id

        if self.qps is not None:
            result['Qps'] = self.qps

        if self.type is not None:
            result['Type'] = self.type

        if self.wh_id is not None:
            result['WhId'] = self.wh_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EndTime') is not None:
            self.end_time = m.get('EndTime')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('IsExpired') is not None:
            self.is_expired = m.get('IsExpired')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('PcaInstanceId') is not None:
            self.pca_instance_id = m.get('PcaInstanceId')

        if m.get('Qps') is not None:
            self.qps = m.get('Qps')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        if m.get('WhId') is not None:
            self.wh_id = m.get('WhId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListAssetCountRequest(DaraModel):
    def __init__(
        self,
        current_page: int = None,
        end_date: int = None,
        show_size: int = None,
        start_date: int = None,
    ):
        self.current_page = current_page
        self.end_date = end_date
        self.show_size = show_size
        self.start_date = start_date

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.end_date is not None:
            result['EndDate'] = self.end_date

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.start_date is not None:
            result['StartDate'] = self.start_date

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('EndDate') is not None:
            self.end_date = m.get('EndDate')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('StartDate') is not None:
            self.start_date = m.get('StartDate')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class ListAssetCountResponseBody(DaraModel):
    def __init__(
        self,
        asset_count_list: List[main_models.ListAssetCountResponseBodyAssetCountList] = None,
        current_page: int = None,
        request_id: str = None,
        show_size: int = None,
        total_count: int = None,
    ):
        self.asset_count_list = asset_count_list
        self.current_page = current_page
        self.request_id = request_id
        self.show_size = show_size
        self.total_count = total_count

    def validate(self):
        if self.asset_count_list:
            for v1 in self.asset_count_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['AssetCountList'] = []
        if self.asset_count_list is not None:
            for k1 in self.asset_count_list:
                result['AssetCountList'].append(k1.to_map() if k1 else None)

        if self.current_page is not None:
            result['CurrentPage'] = self.current_page

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.show_size is not None:
            result['ShowSize'] = self.show_size

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.asset_count_list = []
        if m.get('AssetCountList') is not None:
            for k1 in m.get('AssetCountList'):
                temp_model = main_models.ListAssetCountResponseBodyAssetCountList()
                self.asset_count_list.append(temp_model.from_map(k1))

        if m.get('CurrentPage') is not None:
            self.current_page = m.get('CurrentPage')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('ShowSize') is not None:
            self.show_size = m.get('ShowSize')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class ListAssetCountResponseBodyAssetCountList(DaraModel):
    def __init__(
        self,
        aliyun_asset_count: int = None,
        certificate_count: int = None,
        count_date: int = None,
        domain_asset_count: int = None,
        multi_cloud_asset_count: int = None,
        points: int = None,
    ):
        self.aliyun_asset_count = aliyun_asset_count
        self.certificate_count = certificate_count
        self.count_date = count_date
        self.domain_asset_count = domain_asset_count
        self.multi_cloud_asset_count = multi_cloud_asset_count
        self.points = points

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.aliyun_asset_count is not None:
            result['AliyunAssetCount'] = self.aliyun_asset_count

        if self.certificate_count is not None:
            result['CertificateCount'] = self.certificate_count

        if self.count_date is not None:
            result['CountDate'] = self.count_date

        if self.domain_asset_count is not None:
            result['DomainAssetCount'] = self.domain_asset_count

        if self.multi_cloud_asset_count is not None:
            result['MultiCloudAssetCount'] = self.multi_cloud_asset_count

        if self.points is not None:
            result['Points'] = self.points

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AliyunAssetCount') is not None:
            self.aliyun_asset_count = m.get('AliyunAssetCount')

        if m.get('CertificateCount') is not None:
            self.certificate_count = m.get('CertificateCount')

        if m.get('CountDate') is not None:
            self.count_date = m.get('CountDate')

        if m.get('DomainAssetCount') is not None:
            self.domain_asset_count = m.get('DomainAssetCount')

        if m.get('MultiCloudAssetCount') is not None:
            self.multi_cloud_asset_count = m.get('MultiCloudAssetCount')

        if m.get('Points') is not None:
            self.points = m.get('Points')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DescribePackageStateRequest(DaraModel):
    def __init__(
        self,
        product_code: str = None,
    ):
        # The specifications of the certificate resource plan. Valid values:
        # 
        # *   **digicert-free-1-free** (default): DigiCert single-domain domain validated (DV) certificate in a three-month free trial, available only on the China site (aliyun.com).
        # *   **symantec-free-1-free**: DigiCert single-domain DV certificate in a one-year free trial, available only on the China site (aliyun.com).
        # *   **symantec-dv-1-starter**: DigiCert wildcard DV certificate.
        # *   **symantec-ov-1-personal**: DigiCert single-domain organization validated (OV) certificate.
        # *   **symantec-ov-w-personal**: DigiCert wildcard OV certificate.
        # *   **geotrust-dv-1-starter**: GeoTrust single-domain DV certificate.
        # *   **geotrust-dv-w-starter**: GeoTrust wildcard DV certificate.
        # *   **geotrust-ov-1-personal**: GeoTrust single-domain OV certificate.
        # *   **geotrust-ov-w-personal**: GeoTrust wildcard OV certificate.
        # *   **globalsign-dv-1-personal**: GlobalSign single-domain DV certificate.
        # *   **globalsign-dv-w-advanced**: GlobalSign wildcard DV certificate.
        # *   **globalsign-ov-1-personal**: GlobalSign single-domain OV certificate.
        # *   **globalsign-ov-w-advanced**: GlobalSign wildcard OV certificate.
        # *   **cfca-ov-1-personal**: China Financial Certification Authority (CFCA) single-domain OV certificate, available only on the China site (aliyun.com).
        # *   **cfca-ev-w-advanced**: CFCA wildcard OV certificate, available only on the China site (aliyun.com).
        self.product_code = product_code

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.product_code is not None:
            result['ProductCode'] = self.product_code

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ProductCode') is not None:
            self.product_code = m.get('ProductCode')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_cas20200407 import models as main_models
from darabonba.model import DaraModel

class CreateCertificateForPackageRequestRequest(DaraModel):
    def __init__(
        self,
        company_name: str = None,
        csr: str = None,
        domain: str = None,
        email: str = None,
        phone: str = None,
        product_code: str = None,
        tags: List[main_models.CreateCertificateForPackageRequestRequestTags] = None,
        username: str = None,
        validate_type: str = None,
    ):
        # The company name of the certificate application.
        # 
        # >  This parameter is available only when you apply for OV certificates. For more information, see [Manage company profiles](https://help.aliyun.com/document_detail/198289.html). If you want to apply for a DV certificate, you do not need to add a company profile.
        # 
        # If you specify a company name, the information about the company that is configured in the **Information Management** module is used. If you do not specify this parameter, the information about the most recent company that is added to the **Information Management** module is used.
        self.company_name = company_name
        # The content of the certificate signing request (CSR) file that is manually generated by using OpenSSL or Keytool for the domain name. The key algorithm in the CSR file must be Rivest-Shamir-Adleman (RSA) or elliptic-curve cryptography (ECC), and the key length of the RSA algorithm must be greater than or equal to 2,048 characters. For more information about how to create a CSR file, see [Create a CSR file](https://help.aliyun.com/document_detail/313297.html). If you do not specify this parameter, Certificate Management Service automatically creates a CSR file.
        # 
        # A CSR file contains the information about your server and company. When you apply for a certificate, you must submit the CSR file to the CA. The CA signs the CSR file by using the private key of the root certificate and generates a public key file to issue your certificate.
        # 
        # >  The \\*\\*CN\\*\\* field in CSR file specifies the domain name that is bound to the certificate. You must include the field in the parameter value.
        self.csr = csr
        # The domain name that you want to bind to the certificate. The domain name must meet the following requirements:
        # 
        # *   The domain name must be a single domain name or a wildcard domain name. Example: `*.aliyundoc.com`.
        # *   You can specify multiple domain names. Separate multiple domain names with commas (,). You can specify a maximum of five domain names.
        # *   If you specify multiple domain names, the domain names must be only single domain names or only wildcard domain names. You cannot specify both single domain names and wildcard domain names.
        # 
        # >  If you want to bind multiple domain names to the certificate, you must specify this parameter. You must specify at least one of the Domain parameter and the \\*\\*Csr\\*\\* parameter. If you specify both the Domain parameter and the \\*\\*Csr\\*\\* parameter, the value of the \\*\\*CN\\*\\* field in the \\*\\*Csr\\*\\* parameter is used as the domain name that is bound to the certificate.
        self.domain = domain
        # The email address of the applicant. After the CA receives your certificate application, the CA sends a verification email to the email address that you specify. You must log on to the mailbox, open the mail, and complete the verification of the domain name ownership based on the steps that are described in the email.
        # 
        # If you do not specify this parameter, the information about the most recent contact that is added to the **Information Management** module is used. For more information about how to add a contact to the **Information Management** module, see [Manage contacts](https://help.aliyun.com/document_detail/198262.html).
        self.email = email
        # The contact phone number of the applicant. CA staff can call the phone number to confirm the information in your certificate application.
        # 
        # If you do not specify this parameter, the information about the most recent contact that is added to the **Information Management** module is used. For more information about how to add a contact to the **Information Management** module, see [Manage contacts](https://help.aliyun.com/document_detail/198262.html).
        self.phone = phone
        # The specifications of the certificate that you want to apply for. Valid values:
        # 
        # *   **digicert-free-1-free** (default): DigiCert single-domain domain validated (DV) certificate, which is free and valid for 3 months. This value is available only on the China site (aliyun.com).
        # *   **symantec-free-1-free**: DigiCert single-domain DV certificate, which is free and valid for 1 year. This value is available only on the China site (aliyun.com).
        # *   **symantec-dv-1-starter**: DigiCert wildcard DV certificate.
        # *   **symantec-ov-1-personal**: DigiCert single-domain organization validated (OV) certificate.
        # *   **symantec-ov-w-personal**: DigiCert wildcard OV certificate.
        # *   **geotrust-dv-1-starter**: GeoTrust single-domain DV certificate.
        # *   **geotrust-dv-w-starter**: GeoTrust wildcard DV certificate.
        # *   **geotrust-ov-1-personal**: GeoTrust single-domain OV certificate.
        # *   **geotrust-ov-w-personal**: GeoTrust wildcard OV certificate.
        # *   **globalsign-dv-1-personal**: GlobalSign single-domain DV certificate.
        # *   **globalsign-dv-w-advanced**: GlobalSign wildcard DV certificate.
        # *   **globalsign-ov-1-personal**: GlobalSign single-domain OV certificate.
        # *   **globalsign-ov-w-advanced**: GlobalSign wildcard OV certificate.
        # *   **cfca-ov-1-personal**: China Financial Certification Authority (CFCA) single-domain OV certificate, available only on the China site (aliyun.com).
        # *   **cfca-ev-w-advanced**: CFCA wildcard OV certificate, available only on the China site (aliyun.com).
        self.product_code = product_code
        # The list of tags.
        self.tags = tags
        # The name of the applicant.
        # 
        # If you do not specify this parameter, the information about the most recent contact that is added to the **Information Management** module is used. For more information about how to add a contact to the **Information Management** module, see [Manage contacts](https://help.aliyun.com/document_detail/198262.html).
        self.username = username
        # The verification method of the domain name ownership. Valid values:
        # 
        # *   **DNS**: DNS verification. If you use this method, you must add a TXT record to the DNS records of the domain name in the management platform of the domain name. You must have operation permissions on domain name resolution to verify the ownership of the domain name.
        # *   **FILE**: file verification. If you use this method, you must create a specified file on the DNS server. You must have administrative rights on the DNS server to verify the ownership of the domain name.
        # 
        # For more information about the verification methods, see [Verify the ownership of a domain name](https://help.aliyun.com/document_detail/48016.html).
        self.validate_type = validate_type

    def validate(self):
        if self.tags:
            for v1 in self.tags:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.company_name is not None:
            result['CompanyName'] = self.company_name

        if self.csr is not None:
            result['Csr'] = self.csr

        if self.domain is not None:
            result['Domain'] = self.domain

        if self.email is not None:
            result['Email'] = self.email

        if self.phone is not None:
            result['Phone'] = self.phone

        if self.product_code is not None:
            result['ProductCode'] = self.product_code

        result['Tags'] = []
        if self.tags is not None:
            for k1 in self.tags:
                result['Tags'].append(k1.to_map() if k1 else None)

        if self.username is not None:
            result['Username'] = self.username

        if self.validate_type is not None:
            result['ValidateType'] = self.validate_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CompanyName') is not None:
            self.company_name = m.get('CompanyName')

        if m.get('Csr') is not None:
            self.csr = m.get('Csr')

        if m.get('Domain') is not None:
            self.domain = m.get('Domain')

        if m.get('Email') is not None:
            self.email = m.get('Email')

        if m.get('Phone') is not None:
            self.phone = m.get('Phone')

        if m.get('ProductCode') is not None:
            self.product_code = m.get('ProductCode')

        self.tags = []
        if m.get('Tags') is not None:
            for k1 in m.get('Tags'):
                temp_model = main_models.CreateCertificateForPackageRequestRequestTags()
                self.tags.append(temp_model.from_map(k1))

        if m.get('Username') is not None:
            self.username = m.get('Username')

        if m.get('ValidateType') is not None:
            self.validate_type = m.get('ValidateType')

        return self



class CreateCertificateForPackageRequestRequestTags(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: str = None,
    ):
        # The tag key.
        self.key = key
        # The tag value.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self

